@@ -4,7 +4,7 @@ package Module::Install::Base;
 # Suspend handler for "redefined" warnings
 BEGIN { my $w = $SIG{__WARN__}; $SIG{__WARN__} = sub { $w } };
 
-#line 31
+#line 30
 
 sub new {
     my ($class, %args) = @_;
@@ -18,18 +18,21 @@ sub new {
     bless(\%args, $class);
 }
 
-#line 49
+#line 48
 
 sub AUTOLOAD {
     my $self = shift;
-    goto &{$self->_top->autoload};
+
+    local $@;
+    my $autoload = eval { $self->_top->autoload } or return;
+    goto &$autoload;
 }
 
-#line 60
+#line 62
 
 sub _top { $_[0]->{_top} }
 
-#line 71
+#line 73
 
 sub admin {
     my $self = shift;
@@ -57,4 +60,4 @@ BEGIN { $SIG{__WARN__} = $SIG{__WARN__}->() };
 
 __END__
 
-#line 118
+#line 120
