@@ -65,14 +65,14 @@ sub write {
     $args->{test} = {TESTS => $self->tests} if $self->tests;
 
     if ($] >= 5.005) {
-	$args->{ABSTRACT} = $self->abstract;
-	$args->{AUTHOR} = $self->author;
+        $args->{ABSTRACT} = $self->abstract;
+        $args->{AUTHOR} = $self->author;
     }
     if ( eval($ExtUtils::MakeMaker::VERSION) >= 6.10 ) {
         $args->{NO_META} = 1;
     }
     if ( eval($ExtUtils::MakeMaker::VERSION) > 6.17 ) {
-	# $args->{SIGN} = 1 if $self->sign;  # removed by Martin Thurn
+        $args->{SIGN} = 1 if $self->sign;
     }
     delete $args->{SIGN} unless $self->is_admin;
 
@@ -154,4 +154,4 @@ sub postamble {
 
 __END__
 
-#line 287
+#line 286
